SetFamily

Struct SetFamily 

pub struct SetFamily<N: CddNumber = DefaultNumber> { /* private fields */ }

Implementations

Source

impl<N: CddNumber> SetFamily<N>

pub unsafe fn from_raw(ptr: *mut c_void) -> Self

Safety
  • ptr must be a non-null dd_SetFamilyPtr compatible with the backend N.
  • The pointer must be valid for the lifetime of this wrapper and must be owned by this wrapper (it will be freed on drop).
pub fn as_raw(&self) -> *mut c_void

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn universe_size(&self) -> usize

pub fn to_adjacency_lists(&self) -> Vec<Vec<usize>>